Class: Syndication::Atom::Entry
- Includes:
- Defined in:
- lib/syndication/atom.rb,
lib/syndication/google.rb
Overview
An entry within an Atom feed.
Instance Attribute Summary collapse
-
#author ⇒ Object
Author of entry as a Person object.
-
#categories ⇒ Object
readonly
Array of taxonomic categories for feed.
-
#content ⇒ Object
Content element as Atom::Content object.
-
#contributors ⇒ Object
readonly
Array of Person objects representing contributors.
-
#created ⇒ Object
The DateTime of creation (Atom 0.3, obsolete).
-
#id ⇒ Object
Globally unique ID of Entry.
-
#links ⇒ Object
readonly
Array of Link objects.
-
#published ⇒ Object
The DateTime of publication.
-
#rights ⇒ Object
Copyright or other rights information.
-
#source ⇒ Object
Source feed metadata as Feed object.
-
#summary ⇒ Object
Summary of content.
-
#title ⇒ Object
Title of entry.
-
#updated ⇒ Object
The last update DateTime.
Attributes included from Google
Instance Method Summary collapse
-
#category=(obj) ⇒ Object
Add a Category object to the entry.
-
#contributor=(obj) ⇒ Object
Add a Person to the entry to represent a contributor.
-
#copyright=(x) ⇒ Object
For Atom 0.3 compatibility.
-
#issued=(x) ⇒ Object
For Atom 0.3 compatibility.
-
#link=(obj) ⇒ Object
Add a Link to the entry.
-
#modified=(x) ⇒ Object
For Atom 0.3 compatibility.
Methods included from Google
Methods inherited from Container
#initialize, #parse_date, #store, #store_category, #strip, #tag2method, #tag_end, #tag_start
Constructor Details
This class inherits a constructor from Syndication::Container
Instance Attribute Details
#author ⇒ Object
Author of entry as a Person object.
398 399 400 |
# File 'lib/syndication/atom.rb', line 398 def end |
#categories ⇒ Object (readonly)
Array of taxonomic categories for feed.
404 405 406 |
# File 'lib/syndication/atom.rb', line 404 def categories @categories end |
#content ⇒ Object
Content element as Atom::Content object
412 413 414 |
# File 'lib/syndication/atom.rb', line 412 def content @content end |
#contributors ⇒ Object (readonly)
Array of Person objects representing contributors.
408 409 410 |
# File 'lib/syndication/atom.rb', line 408 def contributors @contributors end |
#created ⇒ Object
The DateTime of creation (Atom 0.3, obsolete)
469 470 471 |
# File 'lib/syndication/atom.rb', line 469 def created parse_date(@created) end |
#id ⇒ Object
Globally unique ID of Entry.
402 403 404 |
# File 'lib/syndication/atom.rb', line 402 def id @id end |
#links ⇒ Object (readonly)
Array of Link objects.
406 407 408 |
# File 'lib/syndication/atom.rb', line 406 def links @links end |
#published ⇒ Object
The DateTime of publication
464 465 466 |
# File 'lib/syndication/atom.rb', line 464 def published parse_date(@published) end |
#rights ⇒ Object
Copyright or other rights information.
400 401 402 |
# File 'lib/syndication/atom.rb', line 400 def rights @rights end |
#source ⇒ Object
Source feed metadata as Feed object.
392 393 394 |
# File 'lib/syndication/atom.rb', line 392 def source @source end |
#summary ⇒ Object
Summary of content.
390 391 392 |
# File 'lib/syndication/atom.rb', line 390 def summary @summary end |
#title ⇒ Object
Title of entry.
388 389 390 |
# File 'lib/syndication/atom.rb', line 388 def title @title end |
#updated ⇒ Object
The last update DateTime
459 460 461 |
# File 'lib/syndication/atom.rb', line 459 def updated parse_date(@updated) end |
Instance Method Details
#category=(obj) ⇒ Object
Add a Category object to the entry
435 436 437 438 439 440 |
# File 'lib/syndication/atom.rb', line 435 def category=(obj) if !defined? @categories @categories = Array.new end @categories.push(obj) end |
#contributor=(obj) ⇒ Object
Add a Person to the entry to represent a contributor
443 444 445 446 447 448 |
# File 'lib/syndication/atom.rb', line 443 def contributor=(obj) if !defined? @contributors @contributors = Array.new end @contributors.push(obj) end |
#copyright=(x) ⇒ Object
For Atom 0.3 compatibility
425 426 427 |
# File 'lib/syndication/atom.rb', line 425 def copyright=(x) @rights = x end |
#issued=(x) ⇒ Object
For Atom 0.3 compatibility
420 421 422 |
# File 'lib/syndication/atom.rb', line 420 def issued=(x) @published = x end |
#link=(obj) ⇒ Object
Add a Link to the entry
451 452 453 454 455 456 |
# File 'lib/syndication/atom.rb', line 451 def link=(obj) if !defined? @links @links = Array.new end @links.push(obj) end |
#modified=(x) ⇒ Object
For Atom 0.3 compatibility
415 416 417 |
# File 'lib/syndication/atom.rb', line 415 def modified=(x) @updated = x end |